==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/balrogs.pl <==
#============================================================================================================
#
#	W[(BALROGS)
#	balrogs.pl
#	-------------------------------------------------------------------------------------
#	2003.11.22 start
#	2004.09.18 VXeςɔύX
#
#============================================================================================================
package	BALROGS;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($obj);
	
	$obj = {
		'SYS'		=> undef,
		'TYPE'		=> undef,
		'SEARCHSET'	=> undef,
		'RESULTSET'	=> undef
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	ݒ
#	-------------------------------------------------------------------------------------
#	@param	$SYS    : MELKOR
#	@param	$mode   : 0:S,1:BBS,2:Xbh
#	@param	$type   : 0:S,1:O,2:{
#			          4:ID(t)
#	@param	$bbs    : BBS($mode=1̏ꍇɎw)
#	@param	$thread : Xbh($mode=2̏ꍇɎw)
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Create
{
	my $this = shift;
	my ($SYS, $mode, $type, $bbs, $thread) = @_;
	my ($pSearchSet, $dir, $set);
	
	$this->{'SYS'} = $SYS;
	$this->{'TYPE'} = $type;
	undef @{$this->{'SEARCHSET'}};
	$pSearchSet = $this->{'SEARCHSET'};
	
	# IS
	if ($mode == 0) {
		require './module/baggins.pl';
		require './module/nazguls.pl';
		my $BBSs = NAZGUL->new;
		my $Threads = BILBO->new;
		my (@bbsSet, @threadSet, $bbsID, $threadID, $set);
		
		$BBSs->Load($SYS);
		$BBSs->GetKeySet('ALL', '', \@bbsSet);
		
		foreach $bbsID (@bbsSet) {
			$dir = $BBSs->Get('DIR', $bbsID);
			
			$SYS->Set('BBS', $dir);
			$Threads->Load($SYS);
			$Threads->GetKeySet('ALL', '', \@threadSet);
			
			foreach $threadID (@threadSet) {
				$set = "$dir<>$threadID";
				push @$pSearchSet, $set;
			}
			undef @threadSet;
		}
	}
	# fS
	elsif ($mode == 1) {
		require './module/baggins.pl';
		my $Threads = BILBO->new;
		my (@threadSet, $threadID, $set);
		
		$SYS->Set('BBS', $bbs);
		$Threads->Load($SYS);
		$Threads->GetKeySet('ALL', '', \@threadSet);
		
		foreach $threadID (@threadSet) {
			$set = "$bbs<>$threadID";
			push @$pSearchSet, $set;
		}
	}
	# XbhS
	elsif ($mode == 2) {
		$set = "$bbs<>$thread";
		push @$pSearchSet, $set;
	}
	# w肪
	else {
		return;
	}
	
	# datW[ǂݍ
	if (! defined $this->{'ARAGORN'}) {
		require './module/gondor.pl';
		$this->{'ARAGORN'} = ARAGORN->new;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	s
#	-------------------------------------------------------------------------------------
#	@param	$word : [h
#	@param	$f    : OʃNAtO
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Run
{
	my $this = shift;
	my ($word, $f) = @_;
	my ($pSearchSet, $bbs, $key);
	
	$pSearchSet = $this->{'SEARCHSET'};
	
	foreach (@$pSearchSet) {
		($bbs, $key) = split(/<>/, $_);
		$this->{'SYS'}->Set('BBS', $bbs);
		$this->{'SYS'}->Set('KEY', $key);
		Search($this, $word);
	}
	return($this->{'RESULTSET'});
}

#------------------------------------------------------------------------------------------------------------
#
#	ʎ擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	ʃZbg
#
#------------------------------------------------------------------------------------------------------------
sub GetResultSet
{
	my $this = shift;
	
	return($this->{'RESULTSET'});
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	$this : thisIuWFNg
#	@param	$word : [h
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Search
{
	my ($this, $word) = @_;
	my ($pDAT, $pResultSet, $SetStr);
	my ($bbs, $key, $i, $bFind, $Path, $pDat, @elem);
	
	$bbs	= $this->{'SYS'}->Get('BBS');
	$key	= $this->{'SYS'}->Get('KEY');
	$Path	= $this->{'SYS'}->Get('BBSPATH') . "/$bbs/dat/$key.dat";
	
	if ($this->{'ARAGORN'}->Load($this->{'SYS'}, $Path, 1)) {
		$pResultSet = $this->{'RESULTSET'};
		$bFind = 0;
		# ׂẴXŃ[v
		for ($i = 0 ; $i < $this->{'ARAGORN'}->Size() ; $i++) {
			$pDat = $this->{'ARAGORN'}->Get($i);
			@elem = split(/<>/, $$pDat);
			# O
			if ($this->{'TYPE'} == 0 || $this->{'TYPE'} & 1) {
				if (index($elem[0], $word) > -1) {
					$elem[0] =~ s/(\Q$word\E)/<span class=res>$word<\/span>/g;
					$bFind = 1;
				}
			}
			# {
			if ($this->{'TYPE'} == 0 || $this->{'TYPE'} & 2) {
				if (index($elem[3], $word) > -1) {
					$elem[3] =~ s/(\Q$word\E)/<span class=res>$word<\/span>/g;
					$bFind = 1;
				}
			}
			# ID or t
			if ($this->{'TYPE'} == 0 || $this->{'TYPE'} & 4) {
				if (index($elem[2], $word) > -1) {
					$elem[2] =~ s/(\Q$word\E)/<span class=res>$word<\/span>/g;
					$bFind = 1;
				}
			}
			if ($bFind) {
				$SetStr = "$bbs<>$key<>" . ($i + 1) . '<>';
				$SetStr .= join('<>', @elem);
				push @$pResultSet, $SetStr;
			}
			$bFind = 0;
		}
		$this->{'RESULTSET'} = $pResultSet;
	}
	$this->{'ARAGORN'}->Close();
}

#============================================================================================================
#	Module END
#============================================================================================================
1;

==> zerochplus_0.7.2.tar.gz: zerochplus_0.7.2/test/module/balrogs.pl <==
#============================================================================================================
#
#	W[(BALROGS)
#
#============================================================================================================
package	BALROGS;

use strict;
#use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $class = shift;
	
	my $obj = {
		'SYS'		=> undef,
		'TYPE'		=> undef,
		'SEARCHSET'	=> undef,
		'RESULTSET'	=> undef,
	};
	bless $obj, $class;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	ݒ
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$mode	0:S,1:BBS,2:Xbh
#	@param	$type	0:S,1:O,2:{
#					4:ID(t)
#	@param	$bbs	BBS($mode=1̏ꍇɎw)
#	@param	$thread	Xbh($mode=2̏ꍇɎw)
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Create
{
	my $this = shift;
	my ($Sys, $mode, $type, $bbs, $thread) = @_;
	
	$this->{'SYS'} = $Sys;
	$this->{'TYPE'} = $type;
	
	$this->{'SEARCHSET'} = [];
	$this->{'RESULTSET'} = [];
	my $pSearchSet = $this->{'SEARCHSET'};
	
	# IS
	if ($mode == 0) {
		require './module/baggins.pl';
		require './module/nazguls.pl';
		my $BBSs = NAZGUL->new;
		
		$BBSs->Load($Sys);
		my @bbsSet = ();
		$BBSs->GetKeySet('ALL', '', \@bbsSet);
		
		my $BBSpath = $Sys->Get('BBSPATH');
		
		foreach my $bbsID (@bbsSet) {
			my $dir = $BBSs->Get('DIR', $bbsID);
			
			# fBNg.0ch_hiddenƂt@CΓǂݔ΂
			next if (-e "$BBSpath/$dir/.0ch_hidden");
			
			$Sys->Set('BBS', $dir);
			my $Threads = BILBO->new;
			$Threads->Load($Sys);
			my @threadSet = ();
			$Threads->GetKeySet('ALL', '', \@threadSet);
			
			foreach my $threadID (@threadSet) {
				my $set = "$dir<>$threadID";
				push @$pSearchSet, $set;
			}
		}
	}
	# fS
	elsif ($mode == 1) {
		require './module/baggins.pl';
		my $Threads = BILBO->new;
		
		$Sys->Set('BBS', $bbs);
		$Threads->Load($Sys);
		my @threadSet = ();
		$Threads->GetKeySet('ALL', '', \@threadSet);
		
		foreach my $threadID (@threadSet) {
			my $set = "$bbs<>$threadID";
			push @$pSearchSet, $set;
		}
	}
	# XbhS
	elsif ($mode == 2) {
		my $set = "$bbs<>$thread";
		push @$pSearchSet, $set;
	}
	# w肪
	else {
		return;
	}
	
	# datW[ǂݍ
	if (! defined $this->{'ARAGORN'}) {
		require './module/gondor.pl';
		$this->{'ARAGORN'} = ARAGORN->new;
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	s
#	-------------------------------------------------------------------------------------
#	@param	$word	[h
#	@param	$f		OʃNAtO
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Run
{
	my $this = shift;
	my ($word, $f) = @_;
	
	my $pSearchSet = $this->{'SEARCHSET'};
	$this->{'RESULTSET'} = [] if ($f);
	
	foreach (@$pSearchSet) {
		my ($bbs, $key) = split(/<>/, $_);
		$this->{'SYS'}->Set('BBS', $bbs);
		$this->{'SYS'}->Set('KEY', $key);
		$this->Search($word);
	}
	return $this->{'RESULTSET'};
}

#------------------------------------------------------------------------------------------------------------
#
#	ʎ擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	ʃZbg
#
#------------------------------------------------------------------------------------------------------------
sub GetResultSet
{
	my $this = shift;
	
	return $this->{'RESULTSET'};
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	$word : [h
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Search
{
	my $this = shift;
	my ($word) = @_;
	
	my $bbs = $this->{'SYS'}->Get('BBS');
	my $key = $this->{'SYS'}->Get('KEY');
	my $Path = $this->{'SYS'}->Get('BBSPATH') . "/$bbs/dat/$key.dat";
	my $ARAGORN = $this->{'ARAGORN'};
	
	if ($ARAGORN->Load($this->{'SYS'}, $Path, 1)) {
		my $pResultSet = $this->{'RESULTSET'};
		my $type = $this->{'TYPE'} || 0x7;
		
		# ׂẴXŃ[v
		for (my $i = 0 ; $i < $ARAGORN->Size() ; $i++) {
			my $bFind = 0;
			my $pDat = $ARAGORN->Get($i);
			my @elem = split(/<>/, $$pDat, -1);
			
			# O
			if ($type & 0x1) {
				if ($elem[0] =~ s/(\Q$word\E)(?![^<>]*>)/<span class="res">$1<\/span>/g) {
					$bFind = 1;
				}
			}
			# {
			if ($type & 0x2) {
				if ($elem[3] =~ s/(\Q$word\E)(?![^<>]*>)/<span class="res">$1<\/span>/g) {
					$bFind = 1;
				}
			}
			# ID or t
			if ($type & 0x4) {
				if ($elem[2] =~ s/(\Q$word\E)(?![^<>]*>)/<span class="res">$1<\/span>/g) {
					$bFind = 1;
				}
			}
			if ($bFind) {
				my $SetStr = "$bbs<>$key<>" . ($i + 1) . '<>';
				$SetStr .= join('<>', @elem);
				push @$pResultSet, $SetStr;
			}
		}
	}
	$ARAGORN->Close();
}

#============================================================================================================
#	Module END
#============================================================================================================
1;
